@@ -29,7 +29,11 @@ import aws_cdk.core
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD"):
+class CfnMicrosoftAD(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD",
+):
     """A CloudFormation ``AWS::DirectoryService::MicrosoftAD``.
 
     see
@@ -37,7 +41,24 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::MicrosoftAD
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        name: str,
+        password: str,
+        vpc_settings: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable],
+        create_alias: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        edition: typing.Optional[str] = None,
+        enable_sso: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::DirectoryService::MicrosoftAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -50,13 +71,28 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         :param enable_sso: ``AWS::DirectoryService::MicrosoftAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::MicrosoftAD.ShortName``.
         """
-        props = CfnMicrosoftADProps(name=name, password=password, vpc_settings=vpc_settings, create_alias=create_alias, edition=edition, enable_sso=enable_sso, short_name=short_name)
+        props = CfnMicrosoftADProps(
+            name=name,
+            password=password,
+            vpc_settings=vpc_settings,
+            create_alias=create_alias,
+            edition=edition,
+            enable_sso=enable_sso,
+            short_name=short_name,
+        )
 
         jsii.create(CfnMicrosoftAD, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnMicrosoftAD":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnMicrosoftAD":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -71,7 +107,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -85,7 +123,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -150,7 +190,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
     @builtins.property
     @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(self) -> typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
         see
@@ -159,12 +201,16 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]) -> None:
+    def vpc_settings(
+        self, value: typing.Union["VpcSettingsProperty", aws_cdk.core.IResolvable]
+    ) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
@@ -173,7 +219,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
+    def create_alias(
+        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+    ) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -192,7 +240,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
 
     @builtins.property
     @jsii.member(jsii_name="enableSso")
-    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def enable_sso(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
@@ -201,7 +251,9 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
+    def enable_sso(
+        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+    ) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -218,8 +270,12 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
     def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
-    @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
-    class VpcSettingsProperty():
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftAD.VpcSettingsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
+    )
+    class VpcSettingsProperty:
         def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
             """
             :param subnet_ids: ``CfnMicrosoftAD.VpcSettingsProperty.SubnetIds``.
@@ -229,8 +285,8 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html
             """
             self._values = {
-                'subnet_ids': subnet_ids,
-                'vpc_id': vpc_id,
+                "subnet_ids": subnet_ids,
+                "vpc_id": vpc_id,
             }
 
         @builtins.property
@@ -240,7 +296,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-subnetids
             """
-            return self._values.get('subnet_ids')
+            return self._values.get("subnet_ids")
 
         @builtins.property
         def vpc_id(self) -> str:
@@ -249,7 +305,7 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-microsoftad-vpcsettings.html#cfn-directoryservice-microsoftad-vpcsettings-vpcid
             """
-            return self._values.get('vpc_id')
+            return self._values.get("vpc_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -258,13 +314,42 @@ class CfnMicrosoftAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_typ
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'VpcSettingsProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "VpcSettingsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'edition': 'edition', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
-class CfnMicrosoftADProps():
-    def __init__(self, *, name: str, password: str, vpc_settings: typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, edition: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-directoryservice.CfnMicrosoftADProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "password": "password",
+        "vpc_settings": "vpcSettings",
+        "create_alias": "createAlias",
+        "edition": "edition",
+        "enable_sso": "enableSso",
+        "short_name": "shortName",
+    },
+)
+class CfnMicrosoftADProps:
+    def __init__(
+        self,
+        *,
+        name: str,
+        password: str,
+        vpc_settings: typing.Union[
+            "CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable
+        ],
+        create_alias: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        edition: typing.Optional[str] = None,
+        enable_sso: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::DirectoryService::MicrosoftAD``.
 
         :param name: ``AWS::DirectoryService::MicrosoftAD.Name``.
@@ -279,14 +364,18 @@ class CfnMicrosoftADProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html
         """
         self._values = {
-            'name': name,
-            'password': password,
-            'vpc_settings': vpc_settings,
+            "name": name,
+            "password": password,
+            "vpc_settings": vpc_settings,
         }
-        if create_alias is not None: self._values["create_alias"] = create_alias
-        if edition is not None: self._values["edition"] = edition
-        if enable_sso is not None: self._values["enable_sso"] = enable_sso
-        if short_name is not None: self._values["short_name"] = short_name
+        if create_alias is not None:
+            self._values["create_alias"] = create_alias
+        if edition is not None:
+            self._values["edition"] = edition
+        if enable_sso is not None:
+            self._values["enable_sso"] = enable_sso
+        if short_name is not None:
+            self._values["short_name"] = short_name
 
     @builtins.property
     def name(self) -> str:
@@ -295,7 +384,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def password(self) -> str:
@@ -304,25 +393,29 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-password
         """
-        return self._values.get('password')
+        return self._values.get("password")
 
     @builtins.property
-    def vpc_settings(self) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union["CfnMicrosoftAD.VpcSettingsProperty", aws_cdk.core.IResolvable]:
         """``AWS::DirectoryService::MicrosoftAD.VpcSettings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-vpcsettings
         """
-        return self._values.get('vpc_settings')
+        return self._values.get("vpc_settings")
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-createalias
         """
-        return self._values.get('create_alias')
+        return self._values.get("create_alias")
 
     @builtins.property
     def edition(self) -> typing.Optional[str]:
@@ -331,16 +424,18 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-edition
         """
-        return self._values.get('edition')
+        return self._values.get("edition")
 
     @builtins.property
-    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def enable_sso(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::MicrosoftAD.EnableSso``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-enablesso
         """
-        return self._values.get('enable_sso')
+        return self._values.get("enable_sso")
 
     @builtins.property
     def short_name(self) -> typing.Optional[str]:
@@ -349,7 +444,7 @@ class CfnMicrosoftADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-microsoftad.html#cfn-directoryservice-microsoftad-shortname
         """
-        return self._values.get('short_name')
+        return self._values.get("short_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -358,11 +453,17 @@ class CfnMicrosoftADProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnMicrosoftADProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnMicrosoftADProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 @jsii.implements(aws_cdk.core.IInspectable)
-class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD"):
+class CfnSimpleAD(
+    aws_cdk.core.CfnResource,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD",
+):
     """A CloudFormation ``AWS::DirectoryService::SimpleAD``.
 
     see
@@ -370,7 +471,25 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
     cloudformationResource:
     :cloudformationResource:: AWS::DirectoryService::SimpleAD
     """
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
+
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        name: str,
+        password: str,
+        size: str,
+        vpc_settings: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"],
+        create_alias: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        description: typing.Optional[str] = None,
+        enable_sso: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Create a new ``AWS::DirectoryService::SimpleAD``.
 
         :param scope: - scope in which this resource is defined.
@@ -384,13 +503,29 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         :param enable_sso: ``AWS::DirectoryService::SimpleAD.EnableSso``.
         :param short_name: ``AWS::DirectoryService::SimpleAD.ShortName``.
         """
-        props = CfnSimpleADProps(name=name, password=password, size=size, vpc_settings=vpc_settings, create_alias=create_alias, description=description, enable_sso=enable_sso, short_name=short_name)
+        props = CfnSimpleADProps(
+            name=name,
+            password=password,
+            size=size,
+            vpc_settings=vpc_settings,
+            create_alias=create_alias,
+            description=description,
+            enable_sso=enable_sso,
+            short_name=short_name,
+        )
 
         jsii.create(CfnSimpleAD, self, [scope, id, props])
 
     @jsii.member(jsii_name="fromCloudFormation")
     @builtins.classmethod
-    def from_cloud_formation(cls, scope: aws_cdk.core.Construct, id: str, resource_attributes: typing.Any, *, finder: aws_cdk.core.ICfnFinder) -> "CfnSimpleAD":
+    def from_cloud_formation(
+        cls,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        resource_attributes: typing.Any,
+        *,
+        finder: aws_cdk.core.ICfnFinder,
+    ) -> "CfnSimpleAD":
         """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
 
         Used in the @aws-cdk/cloudformation-include module.
@@ -405,7 +540,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         """
         options = aws_cdk.core.FromCloudFormationOptions(finder=finder)
 
-        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+        return jsii.sinvoke(
+            cls, "fromCloudFormation", [scope, id, resource_attributes, options]
+        )
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
@@ -419,7 +556,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.invoke(self, "inspect", [inspector])
 
     @jsii.member(jsii_name="renderProperties")
-    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+    def _render_properties(
+        self, props: typing.Mapping[str, typing.Any]
+    ) -> typing.Mapping[str, typing.Any]:
         """
         :param props: -
         """
@@ -498,7 +637,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
     @builtins.property
     @jsii.member(jsii_name="vpcSettings")
-    def vpc_settings(self) -> typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
         see
@@ -507,12 +648,16 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "vpcSettings")
 
     @vpc_settings.setter
-    def vpc_settings(self, value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]) -> None:
+    def vpc_settings(
+        self, value: typing.Union[aws_cdk.core.IResolvable, "VpcSettingsProperty"]
+    ) -> None:
         jsii.set(self, "vpcSettings", value)
 
     @builtins.property
     @jsii.member(jsii_name="createAlias")
-    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
@@ -521,7 +666,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "createAlias")
 
     @create_alias.setter
-    def create_alias(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
+    def create_alias(
+        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+    ) -> None:
         jsii.set(self, "createAlias", value)
 
     @builtins.property
@@ -540,7 +687,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
 
     @builtins.property
     @jsii.member(jsii_name="enableSso")
-    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def enable_sso(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
@@ -549,7 +698,9 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
         return jsii.get(self, "enableSso")
 
     @enable_sso.setter
-    def enable_sso(self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]) -> None:
+    def enable_sso(
+        self, value: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]
+    ) -> None:
         jsii.set(self, "enableSso", value)
 
     @builtins.property
@@ -566,8 +717,12 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
     def short_name(self, value: typing.Optional[str]) -> None:
         jsii.set(self, "shortName", value)
 
-    @jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD.VpcSettingsProperty", jsii_struct_bases=[], name_mapping={'subnet_ids': 'subnetIds', 'vpc_id': 'vpcId'})
-    class VpcSettingsProperty():
+    @jsii.data_type(
+        jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleAD.VpcSettingsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
+    )
+    class VpcSettingsProperty:
         def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
             """
             :param subnet_ids: ``CfnSimpleAD.VpcSettingsProperty.SubnetIds``.
@@ -577,8 +732,8 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html
             """
             self._values = {
-                'subnet_ids': subnet_ids,
-                'vpc_id': vpc_id,
+                "subnet_ids": subnet_ids,
+                "vpc_id": vpc_id,
             }
 
         @builtins.property
@@ -588,7 +743,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-subnetids
             """
-            return self._values.get('subnet_ids')
+            return self._values.get("subnet_ids")
 
         @builtins.property
         def vpc_id(self) -> str:
@@ -597,7 +752,7 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
             see
             :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-directoryservice-simplead-vpcsettings.html#cfn-directoryservice-simplead-vpcsettings-vpcid
             """
-            return self._values.get('vpc_id')
+            return self._values.get("vpc_id")
 
         def __eq__(self, rhs) -> bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -606,13 +761,44 @@ class CfnSimpleAD(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="
             return not (rhs == self)
 
         def __repr__(self) -> str:
-            return 'VpcSettingsProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+            return "VpcSettingsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
 
 
-
-@jsii.data_type(jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleADProps", jsii_struct_bases=[], name_mapping={'name': 'name', 'password': 'password', 'size': 'size', 'vpc_settings': 'vpcSettings', 'create_alias': 'createAlias', 'description': 'description', 'enable_sso': 'enableSso', 'short_name': 'shortName'})
-class CfnSimpleADProps():
-    def __init__(self, *, name: str, password: str, size: str, vpc_settings: typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"], create_alias: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, description: typing.Optional[str]=None, enable_sso: typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]=None, short_name: typing.Optional[str]=None) -> None:
+@jsii.data_type(
+    jsii_type="@aws-cdk/aws-directoryservice.CfnSimpleADProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "name": "name",
+        "password": "password",
+        "size": "size",
+        "vpc_settings": "vpcSettings",
+        "create_alias": "createAlias",
+        "description": "description",
+        "enable_sso": "enableSso",
+        "short_name": "shortName",
+    },
+)
+class CfnSimpleADProps:
+    def __init__(
+        self,
+        *,
+        name: str,
+        password: str,
+        size: str,
+        vpc_settings: typing.Union[
+            aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"
+        ],
+        create_alias: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        description: typing.Optional[str] = None,
+        enable_sso: typing.Optional[
+            typing.Union[bool, aws_cdk.core.IResolvable]
+        ] = None,
+        short_name: typing.Optional[str] = None,
+    ) -> None:
         """Properties for defining a ``AWS::DirectoryService::SimpleAD``.
 
         :param name: ``AWS::DirectoryService::SimpleAD.Name``.
@@ -628,15 +814,19 @@ class CfnSimpleADProps():
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html
         """
         self._values = {
-            'name': name,
-            'password': password,
-            'size': size,
-            'vpc_settings': vpc_settings,
+            "name": name,
+            "password": password,
+            "size": size,
+            "vpc_settings": vpc_settings,
         }
-        if create_alias is not None: self._values["create_alias"] = create_alias
-        if description is not None: self._values["description"] = description
-        if enable_sso is not None: self._values["enable_sso"] = enable_sso
-        if short_name is not None: self._values["short_name"] = short_name
+        if create_alias is not None:
+            self._values["create_alias"] = create_alias
+        if description is not None:
+            self._values["description"] = description
+        if enable_sso is not None:
+            self._values["enable_sso"] = enable_sso
+        if short_name is not None:
+            self._values["short_name"] = short_name
 
     @builtins.property
     def name(self) -> str:
@@ -645,7 +835,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-name
         """
-        return self._values.get('name')
+        return self._values.get("name")
 
     @builtins.property
     def password(self) -> str:
@@ -654,7 +844,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-password
         """
-        return self._values.get('password')
+        return self._values.get("password")
 
     @builtins.property
     def size(self) -> str:
@@ -663,25 +853,29 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-size
         """
-        return self._values.get('size')
+        return self._values.get("size")
 
     @builtins.property
-    def vpc_settings(self) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
+    def vpc_settings(
+        self,
+    ) -> typing.Union[aws_cdk.core.IResolvable, "CfnSimpleAD.VpcSettingsProperty"]:
         """``AWS::DirectoryService::SimpleAD.VpcSettings``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-vpcsettings
         """
-        return self._values.get('vpc_settings')
+        return self._values.get("vpc_settings")
 
     @builtins.property
-    def create_alias(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def create_alias(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.CreateAlias``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-createalias
         """
-        return self._values.get('create_alias')
+        return self._values.get("create_alias")
 
     @builtins.property
     def description(self) -> typing.Optional[str]:
@@ -690,16 +884,18 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-description
         """
-        return self._values.get('description')
+        return self._values.get("description")
 
     @builtins.property
-    def enable_sso(self) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
+    def enable_sso(
+        self,
+    ) -> typing.Optional[typing.Union[bool, aws_cdk.core.IResolvable]]:
         """``AWS::DirectoryService::SimpleAD.EnableSso``.
 
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-enablesso
         """
-        return self._values.get('enable_sso')
+        return self._values.get("enable_sso")
 
     @builtins.property
     def short_name(self) -> typing.Optional[str]:
@@ -708,7 +904,7 @@ class CfnSimpleADProps():
         see
         :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-directoryservice-simplead.html#cfn-directoryservice-simplead-shortname
         """
-        return self._values.get('short_name')
+        return self._values.get("short_name")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -717,7 +913,9 @@ class CfnSimpleADProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'CfnSimpleADProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "CfnSimpleADProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
